pub enum RowSide {
Left,
Right,
Both,
}Expand description
Side of a row within the EDS.
Variants
Left
The row data is on the left of the EDS (i.e. in the ODS).
Right
The row data is on the right of the EDS (i.e. it’s parity data).
Both
The row contains both the original data and the parity data.