pub struct HeaderApi { /* private fields */ }Expand description
Header API for quering bridge nodes.
Implementations
Sourceimpl HeaderApi
impl HeaderApi
Sourcepub async fn head(&self) -> Result<ExtendedHeader>
pub async fn head(&self) -> Result<ExtendedHeader>
Returns the latest header synchronized by the node.
Sourcepub async fn network_head(&self) -> Result<ExtendedHeader>
pub async fn network_head(&self) -> Result<ExtendedHeader>
Returns the latest header announced in the network.
Sourcepub async fn get_by_hash(&self, hash: Hash) -> Result<ExtendedHeader>
pub async fn get_by_hash(&self, hash: Hash) -> Result<ExtendedHeader>
Returns the header of the given hash from the node’s header store.
Sourcepub async fn get_by_height(&self, height: u64) -> Result<ExtendedHeader>
pub async fn get_by_height(&self, height: u64) -> Result<ExtendedHeader>
Returns the header at the given height, if it is currently available.
Sourcepub async fn get_range_by_height(
&self,
from: &ExtendedHeader,
to: u64,
) -> Result<Vec<ExtendedHeader>>
pub async fn get_range_by_height( &self, from: &ExtendedHeader, to: u64, ) -> Result<Vec<ExtendedHeader>>
Returns the given range headers from the node and verifies that they
form a confirmed and continuous chain starting from the from header.
The range is exclusive from both sides.
Sourcepub async fn wait_for_height(&self, height: u64) -> Result<ExtendedHeader>
pub async fn wait_for_height(&self, height: u64) -> Result<ExtendedHeader>
Blocks until the header at the given height has been synced by the node.
Sourcepub async fn sync_state(&self) -> Result<SyncState>
pub async fn sync_state(&self) -> Result<SyncState>
Returns the current state of the node’s Syncer.
Sourcepub async fn sync_wait(&self) -> Result<()>
pub async fn sync_wait(&self) -> Result<()>
Blocks until the node’s Syncer is synced to network head.
Sourcepub fn subscribe(
&self,
) -> Pin<Box<dyn Stream<Item = Result<ExtendedHeader>> + Send + 'static>>
pub fn subscribe( &self, ) -> Pin<Box<dyn Stream<Item = Result<ExtendedHeader>> + Send + 'static>>
Subscribe to recent headers from the network.
Headers will be validated and verified with the one that was previously received.
Example
let client = Client::builder()
.rpc_url("ws://localhost:26658")
.build()
.await?;
let mut headers_rx = client.header().subscribe();
while let Some(header) = headers_rx.next().await {
dbg!(header);
}Auto Trait Implementations
impl Freeze for HeaderApi
impl !RefUnwindSafe for HeaderApi
impl Send for HeaderApi
impl Sync for HeaderApi
impl Unpin for HeaderApi
impl UnsafeUnpin for HeaderApi
impl !UnwindSafe for HeaderApi