pub enum Error {
Rpc(Error),
Grpc(Error),
GrpcBuilder(GrpcClientBuilderError),
Types(Error),
ReadOnlyMode,
ChainIdMissmatch,
InvalidHeight(u64),
InvalidPrivateKey,
RpcEndpointNotSet,
NoAssociatedAddress,
GrpcEndpointNotSet,
}Expand description
Representation of all the errors that can occur when interacting with celestia_client.
Variants
Rpc(Error)
Celestia RPC error.
Grpc(Error)
Celestia gRPC error.
GrpcBuilder(GrpcClientBuilderError)
gRPC client builder error.
Types(Error)
Celestia types error.
ReadOnlyMode
Client is in read-only mode.
ChainIdMissmatch
RPC chain-id and gRPC chain-id missmatch.
InvalidHeight(u64)
Invalid height.
InvalidPrivateKey
Invalid private key.
RpcEndpointNotSet
RPC endpoint is not set.
NoAssociatedAddress
Client does not have associated account address
GrpcEndpointNotSet
gRPC endpoint is not set.
Implementations
Sourceimpl Error
impl Error
Sourcepub fn as_grpc_status(&self) -> Option<&Status>
pub fn as_grpc_status(&self) -> Option<&Status>
Helper that returns the logical error of a gRPC call.
Sourcepub fn as_rpc_call_error(&self) -> Option<&ErrorObjectOwned>
pub fn as_rpc_call_error(&self) -> Option<&ErrorObjectOwned>
Helper that returns the logical error of a RPC call.