pub struct RowNamespaceData {
pub shares: Vec<Share>,
pub proof: Option<Proof>,
}Fields
proof: Option<Proof>Trait Implementations
Sourceimpl Clone for RowNamespaceData
impl Clone for RowNamespaceData
Sourcefn clone(&self) -> RowNamespaceData
fn clone(&self) -> RowNamespaceData
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for RowNamespaceData
impl Debug for RowNamespaceData
Sourceimpl Default for RowNamespaceData
impl Default for RowNamespaceData
Sourcefn default() -> RowNamespaceData
fn default() -> RowNamespaceData
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for RowNamespaceDatawhere
RowNamespaceData: Default,
impl<'de> Deserialize<'de> for RowNamespaceDatawhere
RowNamespaceData: Default,
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<RowNamespaceData, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<RowNamespaceData, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl From<RowNamespaceData> for RowNamespaceData
impl From<RowNamespaceData> for RowNamespaceData
Sourcefn from(namespaced_data: RowNamespaceData) -> RowNamespaceData
fn from(namespaced_data: RowNamespaceData) -> RowNamespaceData
Converts to this type from the input type.
Sourceimpl Message for RowNamespaceData
impl Message for RowNamespaceData
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl Name for RowNamespaceData
impl Name for RowNamespaceData
Sourceconst NAME: &'static str = "RowNamespaceData"
const NAME: &'static str = "RowNamespaceData"
Simple name for this
Message.
This name is the same as it appears in the source .proto file, e.g. FooBar.Sourceconst PACKAGE: &'static str = "shwap"
const PACKAGE: &'static str = "shwap"
Package name this message type is contained in. They are domain-like
and delimited by
., e.g. google.protobuf.Sourcefn full_name() -> String
fn full_name() -> String
Fully-qualified unique name for this
Message.
It’s prefixed with the package name and names of any parent messages,
e.g. google.rpc.BadRequest.FieldViolation.
By default, this is the package name followed by the message name.
Fully-qualified names must be unique within a domain of Type URLs.Sourceimpl PartialEq for RowNamespaceData
impl PartialEq for RowNamespaceData
Sourceimpl Serialize for RowNamespaceData
impl Serialize for RowNamespaceData
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
Sourceimpl TryFrom<RowNamespaceData> for RowNamespaceData
impl TryFrom<RowNamespaceData> for RowNamespaceData
Sourcefn try_from(
value: RowNamespaceData,
) -> Result<RowNamespaceData, <RowNamespaceData as TryFrom<RowNamespaceData>>::Error>
fn try_from( value: RowNamespaceData, ) -> Result<RowNamespaceData, <RowNamespaceData as TryFrom<RowNamespaceData>>::Error>
Performs the conversion.
impl StructuralPartialEq for RowNamespaceData