pub struct ClientBuilder { /* private fields */ }Expand description
A builder for Client.
Implementations
Sourceimpl ClientBuilder
impl ClientBuilder
Sourcepub fn new() -> ClientBuilder
pub fn new() -> ClientBuilder
Returns a new builder.
Sourcepub fn signer<S>(self, pubkey: VerifyingKey, signer: S) -> ClientBuilder
pub fn signer<S>(self, pubkey: VerifyingKey, signer: S) -> ClientBuilder
Set signer and its public key.
Sourcepub fn keypair<S>(self, keypair: S) -> ClientBuilder
pub fn keypair<S>(self, keypair: S) -> ClientBuilder
Set signer from a keypair.
Sourcepub fn private_key(self, bytes: &[u8]) -> ClientBuilder
pub fn private_key(self, bytes: &[u8]) -> ClientBuilder
Set signer from a raw private key.
Sourcepub fn private_key_hex(self, s: &str) -> ClientBuilder
pub fn private_key_hex(self, s: &str) -> ClientBuilder
Set signer from a hex formatted private key.
Sourcepub fn rpc_url(self, url: &str) -> ClientBuilder
pub fn rpc_url(self, url: &str) -> ClientBuilder
Set the RPC endpoint.
Sourcepub fn rpc_auth_token(self, auth_token: &str) -> ClientBuilder
pub fn rpc_auth_token(self, auth_token: &str) -> ClientBuilder
Set the authentication token of RPC endpoint.
Sourcepub fn timeout(self, timeout: Duration) -> ClientBuilder
pub fn timeout(self, timeout: Duration) -> ClientBuilder
Set the request timeout for both RPC and gRPC endpoints.
Sourcepub fn grpc_url(self, url: impl Into<Endpoint>) -> ClientBuilder
pub fn grpc_url(self, url: impl Into<Endpoint>) -> ClientBuilder
Set the gRPC endpoint.
Alias of ClientBuilder::grpc_endpoint.
Accepts Endpoint, &str, or String.
Note
In WASM the endpoint needs to support gRPC-Web.
Sourcepub fn grpc_endpoint(self, endpoint: impl Into<Endpoint>) -> ClientBuilder
pub fn grpc_endpoint(self, endpoint: impl Into<Endpoint>) -> ClientBuilder
Set the gRPC endpoint.
Sourcepub fn grpc_endpoints<I, E>(self, endpoints: I) -> ClientBuilder
pub fn grpc_endpoints<I, E>(self, endpoints: I) -> ClientBuilder
Add multiple gRPC endpoints at once for fallback support.
Accepts Endpoint, &str, or String items.
When multiple endpoints are configured, the client will automatically fall back to the next endpoint if a network-related error occurs.
Note
In WASM the endpoints need to support gRPC-Web.
Sourcepub fn grpc_urls<I, E>(self, urls: I) -> ClientBuilder
pub fn grpc_urls<I, E>(self, urls: I) -> ClientBuilder
Add multiple gRPC endpoints. Alias of ClientBuilder::grpc_endpoints.
Sourcepub fn grpc_transport<B, T>(self, transport: T) -> Selfwhere
B: Body<Data = Bytes> + Send + Unpin + 'static,
<B as Body>::Error: StdError + Send + Sync,
T: Service<Request<TonicBody>, Response = Response<B>> + Send + Sync + Clone + 'static,
<T as Service<Request<TonicBody>>>::Error: StdError + Send + Sync + 'static,
<T as Service<Request<TonicBody>>>::Future: CondSend + 'static,
pub fn grpc_transport<B, T>(self, transport: T) -> Selfwhere
B: Body<Data = Bytes> + Send + Unpin + 'static,
<B as Body>::Error: StdError + Send + Sync,
T: Service<Request<TonicBody>, Response = Response<B>> + Send + Sync + Clone + 'static,
<T as Service<Request<TonicBody>>>::Error: StdError + Send + Sync + 'static,
<T as Service<Request<TonicBody>>>::Future: CondSend + 'static,
Set manually configured gRPC transport