pub struct TxConfig {
pub gas_limit: Option<u64>,
pub gas_price: Option<f64>,
pub memo: Option<String>,
pub priority: TxPriority,
pub confirmation_interval_ms: u64,
}Expand description
Configuration for the transaction.
Fields
gas_limit: Option<u64>Custom gas limit for the transaction (in utia). By default, client will
query gas estimation service to get estimate gas limit.
gas_price: Option<f64>Custom gas price for fee calculation. By default, client will query gas estimation service to get gas price estimate.
memo: Option<String>Memo for the transaction
priority: TxPriorityPriority of the transaction, used with gas estimation service
confirmation_interval_ms: u64Interval between confirmation polling attempts, in milliseconds. Defaults to 500ms.
Implementations
Sourceimpl TxConfig
impl TxConfig
Sourcepub fn with_gas_limit(self, gas_limit: u64) -> TxConfig
pub fn with_gas_limit(self, gas_limit: u64) -> TxConfig
Attach gas limit to this config.
Sourcepub fn with_gas_price(self, gas_price: f64) -> TxConfig
pub fn with_gas_price(self, gas_price: f64) -> TxConfig
Attach gas price to this config.
Sourcepub fn with_priority(self, priority: TxPriority) -> TxConfig
pub fn with_priority(self, priority: TxPriority) -> TxConfig
Specify transaction priority to be used when using gas estimation service
Sourcepub fn with_confirmation_interval_ms(
self,
confirmation_interval_ms: u64,
) -> TxConfig
pub fn with_confirmation_interval_ms( self, confirmation_interval_ms: u64, ) -> TxConfig
Specify the confirmation polling interval in milliseconds.