pub struct ShareApi { /* private fields */ }Expand description
Share API for quering bridge nodes.
Implementations
Performs a subjective validation to check if the shares committed to the header at the specified height are available and retrievable from the network.
Returns Ok(()) if shares are available.
Sourcepub async fn get(
&self,
height: u64,
square_width: u16,
row: u16,
column: u16,
) -> Result<Share>
pub async fn get( &self, height: u64, square_width: u16, row: u16, column: u16, ) -> Result<Share>
Retrieves a specific share from the ExtendedDataSquare at the given
height using its row and column coordinates.
Sourcepub async fn get_with_root(
&self,
height: u64,
row: u16,
column: u16,
) -> Result<Share>
pub async fn get_with_root( &self, height: u64, row: u16, column: u16, ) -> Result<Share>
Retrieves a specific share from the ExtendedDataSquare at the given
height using its row and column coordinates.
NOTE
This method will first fetch and validate the header at a given height and then use it to provide necessary data for validation and post-processing.
If you already have access to the necessary data, it is recommended to use
the equivalent method without the _with_root suffix.
Sourcepub async fn get_samples<I, C>(
&self,
height: u64,
coordinates: I,
) -> Result<Vec<Sample>>
pub async fn get_samples<I, C>( &self, height: u64, coordinates: I, ) -> Result<Vec<Sample>>
Retrieves multiple shares from the ExtendedDataSquare at the given
sample coordinates.
coordinates is a list of (row, column).
Sourcepub async fn get_samples_with_root<I, C>(
&self,
height: u64,
coordinates: I,
) -> Result<Vec<Sample>>
pub async fn get_samples_with_root<I, C>( &self, height: u64, coordinates: I, ) -> Result<Vec<Sample>>
Retrieves multiple shares from the ExtendedDataSquare at the given
sample coordinates.
coordinates is a list of (row, column).
NOTE
This method will first fetch and validate the header at a given height and then use it to provide necessary data for validation and post-processing.
If you already have access to the necessary data, it is recommended to use
the equivalent method without the _with_root suffix.
Sourcepub async fn get_eds(&self, height: u64) -> Result<ExtendedDataSquare>
pub async fn get_eds(&self, height: u64) -> Result<ExtendedDataSquare>
Retrieves the complete ExtendedDataSquare for the specified height.
Sourcepub async fn get_eds_with_root(&self, height: u64) -> Result<ExtendedDataSquare>
pub async fn get_eds_with_root(&self, height: u64) -> Result<ExtendedDataSquare>
Retrieves the complete ExtendedDataSquare for the specified height.
NOTE
This method will first fetch and validate the header at a given height and then use it to provide necessary data for validation and post-processing.
If you already have access to the necessary data, it is recommended to use
the equivalent method without the _with_root suffix.
Sourcepub async fn get_row(
&self,
height: u64,
square_width: u16,
row: u16,
) -> Result<GetRowResponse>
pub async fn get_row( &self, height: u64, square_width: u16, row: u16, ) -> Result<GetRowResponse>
Retrieves all shares from a specific row of the ExtendedDataSquare
at the given height.
Sourcepub async fn get_row_with_root(
&self,
height: u64,
row: u16,
) -> Result<GetRowResponse>
pub async fn get_row_with_root( &self, height: u64, row: u16, ) -> Result<GetRowResponse>
Retrieves all shares from a specific row of the ExtendedDataSquare
at the given height.
NOTE
This method will first fetch and validate the header at a given height and then use it to provide necessary data for validation and post-processing.
If you already have access to the necessary data, it is recommended to use
the equivalent method without the _with_root suffix.
Sourcepub async fn get_namespace_data(
&self,
height: u64,
namespace: Namespace,
) -> Result<NamespaceData>
pub async fn get_namespace_data( &self, height: u64, namespace: Namespace, ) -> Result<NamespaceData>
Retrieves all shares that belong to the specified namespace within the
ExtendedDataSquare at the given height.
The shares are returned in a row-by-row order, maintaining the original layout if the namespace spans multiple rows.
Sourcepub async fn get_namespace_data_with_root(
&self,
height: u64,
namespace: Namespace,
) -> Result<NamespaceData>
pub async fn get_namespace_data_with_root( &self, height: u64, namespace: Namespace, ) -> Result<NamespaceData>
Retrieves all shares that belong to the specified namespace within the
ExtendedDataSquare at the given height.
The shares are returned in a row-by-row order, maintaining the original layout if the namespace spans multiple rows.
NOTE
This method will first fetch and validate the header at a given height and then use it to provide necessary data for validation and post-processing.
If you already have access to the necessary data, it is recommended to use
the equivalent method without the _with_root suffix.
Sourcepub async fn get_range(
&self,
height: u64,
start: u64,
end: u64,
) -> Result<GetRangeResponse>
pub async fn get_range( &self, height: u64, start: u64, end: u64, ) -> Result<GetRangeResponse>
Retrieves a list of shares and their corresponding proof.
The start and end index ignores parity shares and corresponds to ODS.
Sourcepub async fn get_range_with_root(
&self,
height: u64,
start: u64,
end: u64,
) -> Result<GetRangeResponse>
pub async fn get_range_with_root( &self, height: u64, start: u64, end: u64, ) -> Result<GetRangeResponse>
Retrieves a list of shares and their corresponding proof.
The start and end index ignores parity shares and corresponds to ODS.
NOTE
This method will first fetch and validate the header at a given height and then use it to provide necessary data for validation and post-processing.
If you already have access to the necessary data, it is recommended to use
the equivalent method without the _with_root suffix.