pub struct StateApi { /* private fields */ }Expand description
State API for quering and submiting TXs to a consensus node.
Implementations
Sourceimpl StateApi
impl StateApi
Sourcepub fn balance(&self) -> AsyncGrpcCall<u64>
pub fn balance(&self) -> AsyncGrpcCall<u64>
Retrieves the Celestia coin balance for the signer. To query balance without
adding signer to the client, see StateApi::balance_for_address.
Notes
This returns the verified balance which is the one that was reported by
the previous network block. In other words, if you transfer some coins,
you need to wait 1 more block in order to see the new balance. If you want
something more immediate then use StateApi::balance_unverified.
Sourcepub fn balance_unverified(&self) -> AsyncGrpcCall<u64>
pub fn balance_unverified(&self) -> AsyncGrpcCall<u64>
Retrieves the Celestia coin balance for the signer. To query balance without
adding signer to the client, see StateApi::balance_for_address_unverified.
Sourcepub fn balance_for_address(&self, address: &AccAddress) -> AsyncGrpcCall<u64>
pub fn balance_for_address(&self, address: &AccAddress) -> AsyncGrpcCall<u64>
Retrieves the Celestia coin balance for the given address.
Notes
This returns the verified balance which is the one that was reported by
the previous network block. In other words, if you transfer some coins,
you need to wait 1 more block in order to see the new balance. If you want
something more immediate then use StateApi::balance_for_address_unverified.
This is the only method of StateApi that fallbacks to RPC endpoint
when gRPC endpoint wasn’t set.
Sourcepub fn balance_for_address_unverified(
&self,
address: &AccAddress,
) -> AsyncGrpcCall<u64>
pub fn balance_for_address_unverified( &self, address: &AccAddress, ) -> AsyncGrpcCall<u64>
Retrieves the Celestia coin balance for the given address.
Sourcepub fn estimate_gas_price(&self, priority: TxPriority) -> AsyncGrpcCall<f64>
pub fn estimate_gas_price(&self, priority: TxPriority) -> AsyncGrpcCall<f64>
Estimate gas price for given transaction priority based on the gas prices of the transactions in the last five blocks.
If no transaction is found in the last five blocks, it returns the network min gas price.
Sourcepub fn estimate_gas_price_and_usage(
&self,
priority: TxPriority,
tx_bytes: Vec<u8>,
) -> AsyncGrpcCall<GasEstimate>
pub fn estimate_gas_price_and_usage( &self, priority: TxPriority, tx_bytes: Vec<u8>, ) -> AsyncGrpcCall<GasEstimate>
Estimate gas price for transaction with given priority and estimate gas usage for provided serialised transaction.
The gas price estimation is based on the gas prices of the transactions in the last five blocks. If no transaction is found in the last five blocks, it returns the network min gas price.
The gas used is estimated using the state machine simulation.
Sourcepub fn submit_message<M>(
&self,
message: M,
cfg: TxConfig,
) -> AsyncGrpcCall<TxInfo>where
M: IntoProtobufAny + Send + 'static,
pub fn submit_message<M>(
&self,
message: M,
cfg: TxConfig,
) -> AsyncGrpcCall<TxInfo>where
M: IntoProtobufAny + Send + 'static,
Submit given message to celestia network.
Example
use celestia_proto::cosmos::bank::v1beta1::MsgSend;
use celestia_types::state::{Address, Coin};
let client = Client::builder()
.rpc_url("ws://localhost:26658")
.grpc_url("http://localhost:9090")
.private_key_hex("393fdb5def075819de55756b45c9e2c8531a8c78dd6eede483d3440e9457d839")
.build()
.await?;
let msg = MsgSend {
from_address: client.address()?.to_string(),
to_address: "celestia169s50psyj2f4la9a2235329xz7rk6c53zhw9mm".to_string(),
amount: vec![Coin::utia(12345).into()],
};
client
.state()
.submit_message(msg, TxConfig::default())
.await?;Sourcepub fn transfer(
&self,
to_address: &AccAddress,
amount: u64,
cfg: TxConfig,
) -> AsyncGrpcCall<TxInfo>
pub fn transfer( &self, to_address: &AccAddress, amount: u64, cfg: TxConfig, ) -> AsyncGrpcCall<TxInfo>
Sends the given amount of coins from signer’s wallet to the given account address.
Sourcepub fn submit_pay_for_blob(
&self,
blobs: &[Blob],
cfg: TxConfig,
) -> AsyncGrpcCall<TxInfo>
pub fn submit_pay_for_blob( &self, blobs: &[Blob], cfg: TxConfig, ) -> AsyncGrpcCall<TxInfo>
Builds, signs and submits a PayForBlob transaction.
Note
This is the same as BlobApi::submit.
Example
use celestia_types::nmt::Namespace;
use celestia_types::state::{Address, Coin};
use celestia_types::Blob;
let client = Client::builder()
.rpc_url("ws://localhost:26658")
.grpc_url("http://localhost:9090")
.private_key_hex("393fdb5def075819de55756b45c9e2c8531a8c78dd6eede483d3440e9457d839")
.build()
.await?;
let ns = Namespace::new_v0(b"abcd").unwrap();
let blob = Blob::new(ns, "some data".into(), None).unwrap();
client
.state()
.submit_pay_for_blob(&[blob], TxConfig::default())
.await?;Sourcepub fn cancel_unbonding_delegation(
&self,
validator_address: &ValAddress,
amount: u64,
creation_height: u64,
cfg: TxConfig,
) -> AsyncGrpcCall<TxInfo>
pub fn cancel_unbonding_delegation( &self, validator_address: &ValAddress, amount: u64, creation_height: u64, cfg: TxConfig, ) -> AsyncGrpcCall<TxInfo>
Cancels signer’s pending undelegation from a validator.
Sourcepub fn begin_redelegate(
&self,
src_validator_address: &ValAddress,
dest_validator_address: &ValAddress,
amount: u64,
cfg: TxConfig,
) -> AsyncGrpcCall<TxInfo>
pub fn begin_redelegate( &self, src_validator_address: &ValAddress, dest_validator_address: &ValAddress, amount: u64, cfg: TxConfig, ) -> AsyncGrpcCall<TxInfo>
Sends signer’s delegated tokens to a new validator for redelegation.
Sourcepub fn undelegate(
&self,
validator_address: &ValAddress,
amount: u64,
cfg: TxConfig,
) -> AsyncGrpcCall<TxInfo>
pub fn undelegate( &self, validator_address: &ValAddress, amount: u64, cfg: TxConfig, ) -> AsyncGrpcCall<TxInfo>
Undelegates signer’s delegated tokens, unbonding them from the current validator.
Sourcepub fn delegate(
&self,
validator_address: &ValAddress,
amount: u64,
cfg: TxConfig,
) -> AsyncGrpcCall<TxInfo>
pub fn delegate( &self, validator_address: &ValAddress, amount: u64, cfg: TxConfig, ) -> AsyncGrpcCall<TxInfo>
Sends signer’s liquid tokens to a validator for delegation.
Sourcepub fn query_delegation(
&self,
validator_address: &ValAddress,
) -> AsyncGrpcCall<QueryDelegationResponse>
pub fn query_delegation( &self, validator_address: &ValAddress, ) -> AsyncGrpcCall<QueryDelegationResponse>
Retrieves the delegation information between signer and a validator.
Sourcepub fn query_unbonding(
&self,
validator_address: &ValAddress,
) -> AsyncGrpcCall<QueryUnbondingDelegationResponse>
pub fn query_unbonding( &self, validator_address: &ValAddress, ) -> AsyncGrpcCall<QueryUnbondingDelegationResponse>
Retrieves the unbonding status between signer and a validator.
Sourcepub fn query_redelegations(
&self,
src_validator_address: &ValAddress,
dest_validator_address: &ValAddress,
) -> AsyncGrpcCall<QueryRedelegationsResponse>
pub fn query_redelegations( &self, src_validator_address: &ValAddress, dest_validator_address: &ValAddress, ) -> AsyncGrpcCall<QueryRedelegationsResponse>
Retrieves the status of the redelegations between signer and a validator.