pub type NamespacedHash = NamespacedHash<celestia_types::::nmt::NamespacedHash::{constant#0}>;Expand description
Hash that carries info about minimum and maximum Namespace of the hashed data.
NamespacedHash can represent leaves or internal nodes of the Nmt.
If it is a hash of a leaf, then it will be constructed like so:
leaf_namespace | leaf_namespace | Sha256(0x00 | leaf_namespace | data)
If it is a hash of its children nodes, then it will be constructed like so:
min_namespace | max_namespace | Sha256(0x01 | left | right)
Aliased Type
pub struct NamespacedHash { /* private fields */ }